# Contributing to h5preserve

We welcome contributions to h5preserve, subject to our [code of conduct](code_of_conduct.md),
whether it is improvements to the documentation or examples, bug reports or code
improvements.

Bugs should be reported to https://github.org/h5preserve/h5preserve, and pull
requests should be made against master on
https://github.org/h5preserve/h5preserve.

Further details can be found at https://h5preserve.readthedocs.io/en/latest/Contributing.html
